;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'edict-custom-defines) (error "Feature edict-custom-defines already loaded"))

;;;### (autoloads (dui-warn-previously-registered-methods-p dl-warn-conflict-verbosity dl-conflict-warning dl-mode-line-string dl) "dui" "edict/dui.el")
(defconst custom-define-current-source-file "dui.el")

(defgroup dl nil "Customization group for dl-mode interface to edict.el." :group 'edict)

(defcustom dl-mode-line-string " dl" "\
*String indicating activation of dl minor mode in the modeline.

Set to nil to inhibit modeline display." :type '(choice string (const :tag "none" nil)) :group 'dl)

(defcustom dl-conflict-warning "Binding conflict: %s -> %s." "\
*Format string warning about key sequences with conflicting bindings.

Must contain two `%s' descriptors.  The first formats the key sequence,
the second the description of the existing binding." :type 'string :group 'dl)

(defcustom dl-warn-conflict-verbosity 3 "\
*Controls verbosity of binding conflict warnings.

0   turns off warnings entirely.
1   issues a warning for each binding conflict (including sub-keymaps).
2   prints a summary message with a count of conflicts (not including
    sub-keymaps, only keys in those maps that have conflicts).
3   adds verbose detail about what is being done.

Each positive level performs all actions of lower levels." :type 'integer :group 'dl)

(defcustom dui-warn-previously-registered-methods-p t "\
*Warn about previously registered methods." :type 'boolean :group 'dl)

;;;***

;;;### (autoloads (*brackets-allowed-in-english* edict-verbose-electric-henkan edict-use-electric-henkan) "edict-edit" "edict/edict-edit.el")
(defconst custom-define-current-source-file "edict-edit.el")

(defcustom edict-use-electric-henkan nil "\
*Determines whether to use electric henkan mode in edict buffers.

If t, use it; if nil, don't use it.  If 'ask, ask and (re)set the flag." :type '(choice (const :tag "yes" t) (const :tag "no" nil) (const :tag "ask and set flag for this session" ask)) :group 'edict)

(defcustom edict-verbose-electric-henkan t "\
*If non-nil, warns the user of electric changes in henkan state." :type 'boolean :group 'edict)

(defcustom *brackets-allowed-in-english* nil "\
*Allow brackets in the english section of dictionary entries, if non-null." :type 'boolean :group 'edict)

;;;***

;;;### (autoloads (edict-update-sources-alist edict-update-archive-url edict-update-local-mirror edict-update-staging edict-update-file-list edict-update) "edict-update" "edict/edict-update.el")
(defconst custom-define-current-source-file "edict-update.el")

(defgroup edict-update nil "Customization of functions used to keep your EDICT current." :group 'edict)

(defcustom edict-update-file-list nil "\
List of files to update.

If nil, default to the value of `edict-dictionaries'." :type '(repeat file) :group 'edict-update)

(defcustom edict-update-staging "/tmp/edict" "\
Basename of temporary directory for staging EDICT dictionary archives.

Should not end in a slash, because it will be used to generate a unique
name for a directory to be created.  The directory is deleted after use.

If `edict-update-local-mirror' is non-nil, this variable is ignored." :type 'file :group 'edict-update)

(defcustom edict-update-local-mirror nil "\
Path to a local mirror of the EDICT dictionary archives.

Files downloaded here are persistent.  This location takes precedence
over `edict-update-staging'." :type '(choice directory (const :tag "none" nil)) :group 'edict-update)

(defcustom edict-update-archive-url "ftp://ftp.cc.monash.edu.au/pub/nihongo/" "\
URL pointing to a host and directory serving EDICT dictionaries.

Should end with a slash.

Default is Jim Breen's Nihongo Archive at Monash University,
ftp://ftp.cc.monash.edu.au/pub/nihongo/." :type 'string :group 'edict-update)

(defcustom edict-update-sources-alist '(("edict" "edict.gz") ("kanjidic" "kanjidic.gz") ("enamdict" "enamdict.gz")) "\
Map dictionaries to archive name to download.

This isn't really a user customization (should be constant over time and
for different mirrors), but made customizable for convenience." :type '(repeat (list string string)) :group 'edict-update)

;;;***

;;;### (autoloads (*edict-window-location* edict-warn-missing-dictionaries-p edict-match-buffer-name edict-buffer-name edict-dictionaries edict-dictionary-path edict-user-dictionary edict-default-coding-system edict) "edict" "edict/edict.el")
(defconst custom-define-current-source-file "edict.el")

(defgroup edict nil "Per Hammarlund's edict.el interface to Jim Breen's EDICT,\nan English-Japanese dictionary." :group 'mule)

(defcustom edict-default-coding-system 'euc-jp "\
Default coding system for reading dictionary files.

On Unix systems, EDICT is distributed as an EUC file.  For Windows systems
'shift_jis is may be preferable." :type 'symbol :group 'edict)

(defcustom edict-user-dictionary "~/.edict" "\
*This is the edict dictionary where the user's entries will be added.

May be a string (filename), or a cons of a filename and a symbol
\(coding system).  Will be searched first in dictionary lookup." :type '(choice file (cons file symbol)) :group 'edict)

(defcustom edict-dictionary-path nil "\
List of directories to search for edict dictionaries.

The default value contains only the edict subdirectory of the package
data-directory, or if that is missing the package data-directory itself.
Computed using `locate-data-directory' if available, or `package-path' (if
available) and `data-directory'.

Will not find `<package-root>/<package>/etc'-style data directories." :type '(repeat directory) :initialize (lambda (symbol ignored) (unless (default-boundp symbol) (set-default symbol (let (path) (cond ((and (fboundp 'locate-data-directory) (setq path (cond ((locate-data-directory "edict")) ((locate-data-directory "")))))) (t (dolist (dir (cons data-directory (mapcar (lambda (dir) (if dir (concat dir "etc/"))) (reverse (if (boundp 'package-path) package-path)))) path) (if (and dir (eq (car (file-attributes dir)) t)) (progn (setq path (cons dir path)) (let ((file (expand-file-name "edict" dir))) (if (eq (car (file-attributes file)) t) (setq path (cons file path))))))))) (cond ((stringp path) (list path)) ((null path) (message "Couldn't compute default for `edict-dictionary-path'!") nil) ((listp path) path) (t (message "Error in computing default for `edict-dictionary-path'!"))))))) :group 'edict)

(defcustom edict-dictionaries '("edict") "\
*List of edict dictionary specifications.

A dictionary specification is either a string (file name), or a cons
of a file name and a symbol (coding system).  Relative paths are
searched for in each directory in edict-dictionary-path.

All dictionaries found are loaded into edict-buffer for searching.  Usually at
least one of them should be the main edict file.  Use `edict-user-dictionary'
to specify your private dictionary, not this variable.

The auxiliary dictionaries enamdict (proper names) and kanjidic (kanji
database) may be used.

The up-to-date versions of these dictionaries are all available from
ftp://ftp.monash.edu.au/pub/nihongo.  A very small sample dictionary,
edictj.demo, is provided with this package." :type '(choice string (cons string symbol)) :group 'edict)

(defcustom edict-buffer-name "*edict*" "\
The name of `edict-buffer', default \"*edict*\"." :type 'string :group 'edict)

(defcustom edict-match-buffer-name "*edict matches*" "\
The name of `edict-match-buffer', default \"*edict matches*\"." :type 'string :group 'edict)

(defcustom edict-warn-missing-dictionaries-p t "\
Warn about dictionaries specified in edict-dictionaries but not found." :type 'boolean :group 'edict)

(defcustom *edict-window-location* 'top "\
*Location to place edict matches window.  top or bottom.
Doesn't work yet." :type '(const top) :group 'edict)

;;;***

;;;### (autoloads (ts-warn-conflict-verbosity ts-conflict-warning) "ts-mode" "edict/ts-mode.el")
(defconst custom-define-current-source-file "ts-mode.el")

(defcustom ts-conflict-warning "Binding conflict: %s -> %s." "\
*Format string warning about key sequences with conflicting bindings.

Must contain two `%s' descriptors.  The first formats the key sequence,
the second the description of the existing binding." :type 'string)

(defcustom ts-warn-conflict-verbosity 3 "\
*Controls verbosity of binding conflict warnings.

0   turns off warnings entirely.
1   issues a warning for each binding conflict (including sub-keymaps).
2   prints a summary message with a count of conflicts (not including
    sub-keymaps, only keys in those maps that have conflicts).
3   adds verbose detail about what is being done.

Each positive level performs all actions of lower levels." :type 'integer)

;;;***

(provide 'edict-custom-defines)
