;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'dired-custom-defines) (error "Feature dired-custom-defines already loaded"))

;;;### (autoloads (diff-load-hooks diff-do-narrow diff-switches diff) "diff" "dired/diff.el")
(defconst custom-define-current-source-file "diff.el")

(defgroup diff nil "Handling output from Unix diff utility" :group 'tools)

(defcustom diff-switches "-c" "\
*A list of switches (strings) to pass to the diff program." :type '(choice string (repeat string)) :group 'diff)

(defcustom diff-do-narrow nil "\
*If non-nil diff buffers are initialized narrowed to each difference." :type 'boolean :group 'diff)

(defcustom diff-load-hooks nil "\
Hooks to run after loading diff.el" :type 'hook :group 'diff)

;;;***

;;;### (autoloads (dired-do-interactive-permissions dired-do-highlighting dired-faces) "dired-faces" "dired/dired-faces.el")
(defconst custom-define-current-source-file "dired-faces.el")

(defgroup dired-faces nil "Dired faces." :group 'dired)

(defcustom dired-do-highlighting t "\
Set if we should use highlighting according to filetype." :type 'boolean :group 'dired-faces)

(defcustom dired-do-interactive-permissions t "\
Set if we should allow interactive chmod." :type 'boolean :group 'dired-faces)

;;;***

;;;### (autoloads (dired-auto-shell-command-alist) "dired-shell" "dired/dired-shell.el")
(defconst custom-define-current-source-file "dired-shell.el")

(defcustom dired-auto-shell-command-alist nil "\
*Alist of regexps and command lists to guess shell commands.
Each element of this list should be a list of regular expression, and a list
of guesses for shell commands to be used if the file name matches the regular
expression. The list of guesses is evalled. This alist is appended to the front
of dired-default-auto-shell-command-alist before prompting for each shell
command." :group 'dired :type '(repeat (cons (regexp) (choice (repeat (string)) (sexp)))))

;;;***

;;;### (autoloads (dired-setup-keys-hook dired-after-readin-hook dired-before-readin-hook dired-mode-hook dired-grep-load-hook dired-load-hook dired-hooks dired-filename-re-ext dired-omit-regexps dired-omit-extensions dired-cleanup-alist dired-trivial-filenames dired-file-names dired-find-file-compare-truenames dired-refresh-automatically dired-verify-modtimes dired-mail-reader dired-omit-files dired-backup-if-overwrite dired-no-confirm dired-copy-preserve-time dired-dwim-target dired-use-file-transformers dired-find-subdir dired-kept-versions dired-local-variables-file dired-behavior dired-failed-marker-shell dired-keep-marker-kill dired-keep-marker-symlink dired-keep-marker-hardlink dired-keep-marker-copy dired-keep-marker-uucode dired-keep-marker-compress dired-keep-marker-rename dired-markers dired-unshar-program dired-gnutar-program dired-chown-program dired-show-ls-switches dired-ls-F-marks-symlinks dired-use-ls-dired dired-ls-locale dired-listing-switches dired-ls-program dired-compression-method dired-programs dired) "dired" "dired/dired.el")
(defconst custom-define-current-source-file "dired.el")

(defgroup dired nil "Directory editing." :group 'environment)

(defgroup dired-programs nil "External programs used by Dired." :group 'dired)

(defcustom dired-compression-method 'gzip "\
*Type of compression program to use.
Give as a symbol.
Currently-recognized methods are: gzip pack compact compress.
To change this variable use \\[dired-do-compress] with a zero prefix." :type '(choice (const gzip) (const pack) (const pack) (const compact) (const compress)) :group 'dired-programs)

(defcustom dired-ls-program "ls" "\
*Absolute or relative name of the ls program used by dired." :type 'string :group 'dired-programs)

(defcustom dired-listing-switches "-al" "\
*Switches passed to ls for dired. MUST contain the `l' option.
Can contain even `h', `F', `b', `i' and `s'." :type '(choice string (repeat string)) :group 'dired-programs)

(defcustom dired-ls-locale nil "\
*Locale to use when running `dired-ls-program'.
If non-nil, Dired will set the environment variable LC_ALL
to this value.  Setting it to \"POSIX\" may avoid problems Dired
has with parsing non-English locales." :type '(choice (const nil) (const "POSIX") string) :group 'dired-programs)

(defcustom dired-use-ls-dired (and (string-match "gnu\\|linux" system-configuration) (if (featurep 'xemacs) (and (fboundp 'emacs-version>=) (emacs-version>= 21 5)) (and (boundp 'emacs-major-version) (boundp 'emacs-minor-version) (or (> emacs-major-version 21) (and (= emacs-major-version 21) (>= emacs-minor-version 4)))))) "\
Non-nil means Dired should use `ls --dired'." :type 'boolean :group 'dired-programs)

(defcustom dired-ls-F-marks-symlinks (memq system-type '(aix-v3 hpux silicon-graphics-unix)) "\
*Informs dired about how ls -lF marks symbolic links.
Set this to t if `dired-ls-program' with -lF marks the name of the symbolic
link itself with a trailing @.

For example: If foo is a link pointing to bar, and \"ls -F bar\" gives

     ...   bar -> foo

set this variable to nil. If it gives

      ...   bar@ -> foo

set this variable to t.

Dired checks if there is really a @ appended.  Thus, if you have a
marking ls program on one host and a non-marking on another host, and
don't care about symbolic links which really end in a @, you can
always set this variable to t.

If you use efs, it will make this variable buffer-local, and control
it according to its assessment of how the remote host marks symbolic
links." :type 'boolean :group 'dired-programs)

(defcustom dired-show-ls-switches nil "\
*If non-nil dired will show the dired ls switches on the modeline.
If nil, it will indicate how the files are sorted by either \"by name\" or
\"by date\". If it is unable to recognize the sorting defined by the switches,
then the switches will be shown explicitly on the modeline, regardless of the
setting of this variable." :type 'boolean :group 'dired-programs)

(defcustom dired-chown-program (if (memq system-type '(hpux dgux usg-unix-v linux)) "chown" "/etc/chown") "\
*Name of chown command (usually `chown' or `/etc/chown')." :type 'string :group 'dired-programs)

(defcustom dired-gnutar-program nil "\
*If non-nil, name of the GNU tar executable (e.g. \"tar\" or \"gnutar\").
GNU tar's `z' switch is used for compressed tar files.
If you don't have GNU tar, set this to nil: a pipe using `zcat' is then used." :type '(choice string (const nil)) :group 'dired-programs)

(defcustom dired-unshar-program nil "\
*Set to the name of the unshar program, if you have it." :type '(choice string (const nil)) :group 'dired-programs)

(defgroup dired-markers nil "Dealing with markers." :group 'dired)

(defcustom dired-keep-marker-rename t "\
*Controls marking of renamed files.
If t, files keep their previous marks when they are renamed.
If a character, renamed files (whether previously marked or not)
are afterward marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-compress t "\
*Controls marking of compressed or uncompressed files.
If t, files keep their previous marks when they are compressed.
If a character, compressed or uncompressed files (whether previously
marked or not) are afterward marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-uucode ?U "\
*Controls marking of uuencoded or uudecoded files.
If t, files keep their previous marks when they are uuencoded.
If a character, uuencoded or uudecoded files (whether previously
marked or not) are afterward marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-copy ?C "\
*Controls marking of copied files.
If t, copied files are marked if and as the corresponding original files were.
If a character, copied files are unconditionally marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-hardlink ?H "\
*Controls marking of newly made hard links.
If t, they are marked if and as the files linked to were marked.
If a character, new links are unconditionally marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-symlink ?S "\
*Controls marking of newly made symbolic links.
If t, they are marked if and as the files linked to were marked.
If a character, new links are unconditionally marked with that character." :type '(choice (const t) character) :group 'dired-markers)

(defcustom dired-keep-marker-kill ?K "\
*When killed file lines are redisplayed, they will have this marker.
Setting this to nil means that they will not have any marker." :type '(choice (const nil) character) :group 'dired-markers)

(defcustom dired-failed-marker-shell ?! "\
*If non-nil, a character with which to mark files of failed shell commands.
Applies to the command `dired-do-shell-command'.  Files for which the shell
command has a nonzero exit status will be marked with this character" :type '(choice (const nil) character) :group 'dired-markers)

(defgroup dired-behavior nil "Dired behavior." :group 'dired)

(defcustom dired-local-variables-file ".dired" "\
*If non-nil, filename for local variables for Dired.
If Dired finds a file with that name in the current directory, it will
temporarily insert it into the dired buffer and run `hack-local-variables'.

Type \\[info] and `g' `(emacs)File Variables' `RET' for more info on
local variables." :type 'string :group 'dired-behavior)

(defcustom dired-kept-versions 2 "\
*When cleaning directory, number of versions to keep." :type 'integer :group 'dired-behavior)

(defcustom dired-find-subdir nil "\
*Determines whether dired tries to lookup a subdir in existing buffers.
If non-nil, dired does not make a new buffer for a directory if it can be
found (perhaps as subdir) in some existing dired buffer. If there are several
dired buffers for a directory, then the most recently used one is chosen.

Dired avoids switching to the current buffer, so that if you have
a normal and a wildcard buffer for the same directory, C-x d RET will
toggle between those two." :type 'boolean :group 'dired-behavior)

(defcustom dired-use-file-transformers t "\
*Determines whether dired uses file transformers.
If non-nil `dired-do-shell-command' will apply file transformers to file names.
See \\[describe-function] for dired-do-shell-command for more information." :type 'boolean :group 'dired-behavior)

(defcustom dired-dwim-target nil "\
*If non-nil, dired tries to guess a default target directory.
This means that if there is a dired buffer displayed in the next window,
use its current subdir, instead of the current subdir of this dired buffer.
The target is put in the prompt for file copy, rename, etc." :type 'boolean :group 'dired-behavior)

(defcustom dired-copy-preserve-time t "\
*If non-nil, Dired preserves the last-modified time in a file copy.
\(This works on only some systems.)\\<dired-mode-map>
Use `\\[dired-do-copy]' with a zero prefix argument to toggle its value." :type 'boolean :group 'dired-behavior)

(defcustom dired-no-confirm nil "\
*If non-nil, a list of symbols for commands dired should not confirm.
It can be a sublist of

  '(byte-compile chgrp chmod chown compress copy delete hardlink load
    move print shell symlink uncompress recursive-delete kill-file-buffer
    kill-dired-buffer patch create-top-dir revert-subdirs)

The meanings of most of the symbols are obvious.  A few exceptions:

    'compress applies to compression or decompression by any of the
     compression program in `dired-compression-method-alist'.

    'kill-dired-buffer applies to offering to kill dired buffers for
     directories which have been deleted.

    'kill-file-buffer applies to offering to kill buffers visiting files
     which have been deleted.

    'recursive-delete applies to recursively deleting non-empty
     directories, and all of their contents.

    'create-top-dir applies to `dired-up-directory' creating a new top level
     directory for the dired buffer.

    'revert-subdirs applies to re-reading subdirectories which have
     been modified on disk.

Note that this list also applies to remote files accessed with efs
or ange-ftp." :type '(set (const byte-compile) (const chgrp) (const chmod) (const chown) (const compress) (const copy) (const delete) (const hardlink) (const load) (const move) (const print) (const shell) (const symlink) (const uncompress) (const recursive-delete) (const recursive-copy) (const kill-file-buffer) (const kill-dired-buffer) (const patch) (const create-top-dir) (const revert-subdirs)) :group 'dired-behavior)

(defcustom dired-backup-if-overwrite nil "\
*Non-nil if Dired should ask about making backups before overwriting files.
Special value 'always suppresses confirmation." :type 'boolean :group 'dired-behavior)

(defcustom dired-omit-files nil "\
*If non-nil un-interesting files will be omitted from this dired buffer.
Use \\[dired-omit-toggle] to see these files. (buffer local)" :type 'boolean :group 'dired-behavior)

(defcustom dired-mail-reader 'vm "\
*Mail reader used by dired for dired-read-mail (\\[dired-read-mail]).
The symbols 'rmail and 'vm are the only two allowed values." :type '(choice (const rmail) (const vm)) :group 'dired-behavior)

(defcustom dired-verify-modtimes t "\
*If non-nil dired will revert dired buffers for modified subdirectories.
See also dired-no-confirm <V>." :type 'boolean :group 'dired-behavior)

(defcustom dired-refresh-automatically t "\
*If non-nil, refresh dired buffers automatically after file operations." :type 'boolean :group 'dired-behavior)

(defcustom dired-find-file-compare-truenames t "\
If nil, set find-file-compare-truenames to nil while opening dired buffer" :type 'boolean :group 'dired-behavior)

(defgroup dired-file-names nil "How Dired deals with files with certain names." :group 'dired)

(defcustom dired-trivial-filenames "\\`\\.\\.?\\'\\|\\`#" "\
*Regexp of files to skip when finding first file of a directory listing.
A value of nil means move to the subdir line.
A value of t means move to first file." :type 'string :group 'dired-file-names)

(defcustom dired-cleanup-alist (list '("tex" ".toc" ".log" ".aux" ".dvi") '("latex" ".toc" ".log" ".aux" ".idx" ".lof" ".lot" ".glo" ".dvi") '("bibtex" ".blg" ".bbl") '("texinfo" ".cp" ".cps" ".fn" ".fns" ".ky" ".kys" ".pg" ".pgs" ".tp" ".tps" ".vr" ".vrs") '("patch" ".rej" ".orig") '("backups" "~") (cons "completion-ignored-extensions" completion-ignored-extensions)) "\
*Alist of extensions for temporary files created by various programs.
Used by `dired-cleanup'." :type '(repeat (list (string :tag "program") (repeat :tag "extensions" :inline t string))) :group 'dired-file-names)

(defcustom dired-omit-extensions (let ((alist dired-cleanup-alist) x result) (while alist (setq x (cdr (car alist)) alist (cdr alist)) (while x (or (member (car x) result) (setq result (cons (car x) result))) (setq x (cdr x)))) result) "\
*List of extensions for file names that will be omitted (buffer-local).
This only has effect when the subdirectory is in omission mode.
To make omission mode the default, set `dired-omit-files' to t.
See also `dired-omit-regexps'." :type '(repeat string) :group 'dired-file-names)

(defcustom dired-omit-regexps '("\\`#" "\\`\\.") "\
*File names matching these regexp may be omitted (buffer-local).
This only has effect when the subdirectory is in omission mode.
To make omission mode the default, set `dired-omit-files' to t.
This only has effect when `dired-omit-files' is t.
See also `dired-omit-extensions'." :type '(repeat regexp) :group 'dired-file-names)

(defcustom dired-filename-re-ext "\\..+\\'" "\
*Defines what is the extension of a file name.
\(match-beginning 0) for this regexp in the file name without directory will
be taken to be the start of the extension." :type 'string :group 'dired-file-names)

(defgroup dired-hooks nil "Dired hooks." :group 'dired)

(defcustom dired-load-hook nil "\
Run after loading dired.
You can customize key bindings or load extensions with this." :type 'hook :group 'dired-hooks)

(defcustom dired-grep-load-hook nil "\
Run after loading dired-grep." :type 'hook :group 'dired-hooks)

(defcustom dired-mode-hook nil "\
Run at the very end of dired-mode." :type 'hook :group 'dired-hooks)

(defcustom dired-before-readin-hook nil "\
Hook run before a dired buffer is newly read in, created,or reverted." :type 'hook :group 'dired-hooks)

(defcustom dired-after-readin-hook nil "\
Hook run after each listing of a file or directory.
The buffer is narrowed to the new listing." :type 'hook :group 'dired-hooks)

(defcustom dired-setup-keys-hook nil "\
Hook run when dired sets up its keymap.
This happens the first time that `dired-mode' is called, and runs after
`dired-mode-hook'.  This hook can be used to make alterations to the
dired keymap." :type 'hook :group 'dired-hooks)

;;;***

(provide 'dired-custom-defines)
