;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'edebug-custom-defines) (error "Feature edebug-custom-defines already loaded"))

;;;### (autoloads (custom-print-vectors print-circle print-level cust-print) "cust-print" "edebug/cust-print.el")
(defconst custom-define-current-source-file "cust-print.el")

(defgroup cust-print nil "Handles print-level and print-circle." :prefix "print-" :group 'lisp :group 'extensions)

(defcustom print-level nil "\
*Controls how many levels deep a nested data object will print.

If nil, printing proceeds recursively and may lead to
max-lisp-eval-depth being exceeded or an error may occur:
`Apparently circular structure being printed.'
Also see `print-length' and `print-circle'.

If non-nil, components at levels equal to or greater than `print-level'
are printed simply as `#'.  The object to be printed is at level 0,
and if the object is a list or vector, its top-level components are at
level 1." :type '(choice (const nil) integer) :group 'cust-print)

(defcustom print-circle nil "\
*Controls the printing of recursive structures.

If nil, printing proceeds recursively and may lead to
`max-lisp-eval-depth' being exceeded or an error may occur:
\"Apparently circular structure being printed.\"  Also see
`print-length' and `print-level'.

If non-nil, shared substructures anywhere in the structure are printed
with `#N=' before the first occurrence (in the order of the print
representation) and `#N#' in place of each subsequent occurrence,
where N is a positive decimal integer.

There is no way to read this representation in standard Emacs,
but if you need to do so, try the cl-read.el package." :type 'boolean :group 'cust-print)

(defcustom custom-print-vectors nil "\
*Non-nil if printing of vectors should obey print-level and print-length.

For Emacs 18, setting print-level, or adding custom print list or
vector handling will make this happen anyway.  Emacs 19 obeys
print-level, but not for vectors." :type 'boolean :group 'cust-print)

;;;***

;;;### (autoloads (edebug-sit-for-seconds edebug-global-break-condition edebug-on-quit edebug-on-error edebug-unwrap-results edebug-print-circle edebug-print-level edebug-print-length edebug-continue-kbd-macro edebug-test-coverage edebug-trace edebug-initial-mode edebug-save-displayed-buffer-points edebug-save-windows edebug-eval-macro-args edebug-all-forms edebug-all-defs edebug-setup-hook edebug) "edebug" "edebug/edebug.el")
(defconst custom-define-current-source-file "edebug.el")

(defgroup edebug nil "A source-level debugger for Emacs Lisp" :group 'lisp)

(defcustom edebug-setup-hook nil "\
*Functions to call before edebug is used.
Each time it is set to a new value, Edebug will call those functions
once and then `edebug-setup-hook' is reset to nil.  You could use this
to load up Edebug specifications associated with a package you are
using but only when you also use Edebug." :type 'hook :group 'edebug)

(defcustom edebug-all-defs nil "\
*If non-nil, evaluation of any defining forms will instrument for Edebug.
This applies to `eval-defun', `eval-region', `eval-buffer', and
`eval-current-buffer'.  `eval-region' is also called by
`eval-last-sexp', and `eval-print-last-sexp'.

You can use the command `edebug-all-defs' to toggle the value of this
variable.  You may wish to make it local to each buffer with
\(make-local-variable 'edebug-all-defs) in your
`emacs-lisp-mode-hook'." :type 'boolean :group 'edebug)

(defcustom edebug-all-forms nil "\
*Non-nil evaluation of all forms will instrument for Edebug.
This doesn't apply to loading or evaluations in the minibuffer.
Use the command `edebug-all-forms' to toggle the value of this option." :type 'boolean :group 'edebug)

(defcustom edebug-eval-macro-args nil "\
*Non-nil means all macro call arguments may be evaluated.
If this variable is nil, the default, Edebug will *not* wrap
macro call arguments as if they will be evaluated.
For each macro, a `edebug-form-spec' overrides this option.
So to specify exceptions for macros that have some arguments evaluated
and some not, you should specify an `edebug-form-spec'." :type 'boolean :group 'edebug)

(defcustom edebug-save-windows t "\
*If non-nil, Edebug saves and restores the window configuration.
That takes some time, so if your program does not care what happens to
the window configurations, it is better to set this variable to nil.

If the value is a list, only the listed windows are saved and
restored.

`edebug-toggle-save-windows' may be used to change this variable." :type '(choice boolean (repeat string)) :group 'edebug)

(defcustom edebug-save-displayed-buffer-points nil "\
*If non-nil, save and restore point in all displayed buffers.

Saving and restoring point in other buffers is necessary if you are
debugging code that changes the point of a buffer which is displayed
in a non-selected window.  If Edebug or the user then selects the
window, the buffer's point will be changed to the window's point.

Saving and restoring point in all buffers is expensive, since it
requires selecting each window twice, so enable this only if you need
it." :type 'boolean :group 'edebug)

(defcustom edebug-initial-mode 'step "\
*Initial execution mode for Edebug, if non-nil.  If this variable
is non-@code{nil}, it specifies the initial execution mode for Edebug
when it is first activated.  Possible values are step, next, go,
Go-nonstop, trace, Trace-fast, continue, and Continue-fast." :type '(choice (const step) (const next) (const go) (const Go-nonstop) (const trace) (const Trace-fast) (const continue) (const Continue-fast)) :group 'edebug)

(defcustom edebug-trace nil "\
*Non-nil means display a trace of function entry and exit.
Tracing output is displayed in a buffer named `*edebug-trace*', one
function entry or exit per line, indented by the recursion level.

You can customize by replacing functions `edebug-print-trace-before'
and `edebug-print-trace-after'." :type 'boolean :group 'edebug)

(defcustom edebug-test-coverage nil "\
*If non-nil, Edebug tests coverage of all expressions debugged.
This is done by comparing the result of each expression
with the previous result. Coverage is considered OK if two different
results are found.

Use `edebug-display-freq-count' to display the frequency count and
coverage information for a definition." :type 'boolean :group 'edebug)

(defcustom edebug-continue-kbd-macro nil "\
*If non-nil, continue defining or executing any keyboard macro.
Use this with caution since it is not debugged." :type 'boolean :group 'edebug)

(defcustom edebug-print-length 50 "\
*Default value of `print-length' to use while printing results in Edebug." :type 'integer :group 'edebug)

(defcustom edebug-print-level 50 "\
*Default value of `print-level' to use while printing results in Edebug." :type 'integer :group 'edebug)

(defcustom edebug-print-circle t "\
*Default value of `print-circle' to use while printing results in Edebug." :type 'boolean :group 'edebug)

(defcustom edebug-unwrap-results nil "\
*Non-nil if Edebug should unwrap results of expressions.
This is useful when debugging macros where the results of expressions
are instrumented expressions.  But don't do this when results might be
circular or an infinite loop will result." :type 'boolean :group 'edebug)

(defcustom edebug-on-error t "\
*Value bound to `debug-on-error' while Edebug is active.

If `debug-on-error' is non-nil, that value is still used.

If the value is a list of signal names, Edebug will stop when any of
these errors are signaled from Lisp code whether or not the signal is
handled by a `condition-case'.  This option is useful for debugging
signals that *are* handled since they would otherwise be missed.
After execution is resumed, the error is signaled again." :type '(choice (const :tag "off") (repeat :menu-tag "When" :value (nil) (symbol :format "%v")) (const :tag "always" t)) :group 'edebug)

(defcustom edebug-on-quit t "\
*Value bound to `debug-on-quit' while Edebug is active." :type 'boolean :group 'edebug)

(defcustom edebug-global-break-condition nil "\
*If non-nil, an expression to test for at every stop point.
If the result is non-nil, then break.  Errors are ignored." :type 'sexp :group 'edebug)

(defcustom edebug-sit-for-seconds 1 "\
*Number of seconds to pause when execution mode is `trace'." :type 'number :group 'edebug)

;;;***

(provide 'edebug-custom-defines)
