;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'mmm-mode-custom-defines) (error "Feature mmm-mode-custom-defines already loaded"))

;;;### (autoloads (mmm-never-modes mmm-global-mode mmm-major-mode-hook mmm-mode-hook mmm-use-old-command-keys mmm-insert-modifiers mmm-command-modifiers mmm-mode-prefix-key mmm-delimiter-mode mmm-major-mode-preferences mmm-mode-ext-classes-alist mmm-submode-mode-line-format mmm-mode-string mmm-submode-decoration-level mmm-faces mmm) "mmm-vars" "mmm-mode/mmm-vars.el")
(defconst custom-define-current-source-file "mmm-vars.el")

(defgroup mmm nil "Multiple Major Modes in one buffer." :group 'tools)

(defgroup mmm-faces nil "Faces and coloring for submode regions.\nIn general, only background colors should be set, to avoid interfering\nwith font-lock." :group 'mmm)

(defcustom mmm-submode-decoration-level 1 "\
*Amount of coloring to use in submode regions.
Should be either 0, 1, or 2, representing None, Low, and High amounts
of coloring respectively.
* None (0) means to use no coloring at all.
* Low (1) means to use `mmm-default-submode-face' for all submode
  regions (except for \"non-submode\" regions, i.e. those that are of
  the primary mode) and `mmm-delimiter-face' for region delimiters.
* High (2) means to use different faces for different types of submode
  regions and delimiters, such as initialization code, expressions that
  are output, declarations, and so on, as specified by the submode
  class.  The default faces are still used for regions that do not
  specify a face." :group 'mmm-faces :type '(choice (const :tag "None" 0) (const :tag "Low" 1) (const :tag "High" 2)))

(defcustom mmm-mode-string " MMM" "\
*String to display in mode line as MMM minor mode indicator." :group 'mmm :type 'string)

(defcustom mmm-submode-mode-line-format "~M[~m]" "\
*Format of the mode-line display when point is in a submode region.

~M is replaced by the name of the primary major mode (which may be
replaced by a combined-mode function, see the info documentation).

~m is replaced by the submode region overlay's `display-name'
property, if it has one.  Otherwise it is replaced by the mode name of
the submode region.

If `mmm-primary-mode-display-name' is non-nil, then this variable is
used even when point is not in a submode region (i.e. it is in a
primary mode region), with ~m being replaced by the value of that
variable." :group 'mmm :type 'string)

(defcustom mmm-mode-ext-classes-alist nil "\
Alist of submode classes for major modes and/or file extensions.
This variable can now be directly modified.

Elements look like (MODE EXT CLASS), where MODE is a major mode, EXT
is a regexp to match a filename such as in `auto-mode-alist', and
CLASS is a submode class. CLASS is activated in all buffers in mode
MODE (if non-nil) and whose filenames match EXT (if non-nil). If
both MODE and EXT are nil, CLASS is activated in all buffers. If CLASS
is the symbol t, MMM Mode is turned on in all buffers matching MODE
and EXT, but no classes are activated.

See `mmm-global-mode'." :group 'mmm :type '(repeat (list (symbol :tag "Major Mode") (string :tag "Filename Regexp") (symbol :tag "Class"))) :require 'mmm-mode)

(defcustom mmm-major-mode-preferences '((perl cperl-mode perl-mode) (javascript javascript-mode c++-mode) (java jde-mode java-mode c++-mode) (css css-mode c++-mode)) "\
User preferences about what major modes to use.
Each element has the form (LANGUAGE . MODES) where LANGUAGE is the
name of a programming language such as `perl' as a symbol, and MODES
is a list of possible major modes to use, such as `cperl-mode' or
`perl-mode'.  The first element of MODES which is `fboundp' is used
for submodes of LANGUAGE.  The last element of MODES should be a mode
which will always be available." :group 'mmm :type '(repeat (cons symbol (repeat (restricted-sexp :match-alternatives (fboundp))))))

(defcustom mmm-delimiter-mode 'fundamental-mode "\
Major mode used by default for delimiter regions.
Classes are encouraged to override this by providing a delimiter-mode
parameter-- see `mmm-classes-alist'." :group 'mmm :type 'function)

(defcustom mmm-mode-prefix-key [(control ?c) ?%] "\
Prefix key for the MMM Minor Mode Keymap." :group 'mmm :type 'vector)

(defcustom mmm-command-modifiers '(control) "\
List of key modifiers for MMM command keys.
The MMM commands in the MMM Mode map, after `mmm-mode-prefix-key',
are bound to default keys with these modifiers added. This variable
must be set before MMM Mode is loaded to have an effect.

It is suggested that the value of this variable be either nil or
\(control), as the default keys are either plain keys or have only a
meta modifier. The shift modifier is not particularly portable between
Emacsen. The values of this variable and `mmm-insert-modifiers' should
be disjoint." :group 'mmm :type '(repeat (symbol :tag "Modifier")))

(defcustom mmm-insert-modifiers 'nil "\
List of key modifiers for MMM submode insertion keys.
When a key pressed after `mmm-mode-prefix-key' has no MMM Mode command
binding, and its modifiers include these, then its basic type, plus any
modifiers in addition to these, is looked up in classes' :insert
specifications.

It is suggested that the value of this variable be either nil or
\(control), allowing submode classes to specify the presence or
absence of the meta modifier. The shift modifier is not particularly
portable between Emacsen. The values of `mmm-command-modifiers' and
this variable should be disjoint." :group 'mmm :type '(repeat (symbol :tag "Modifier")))

(defcustom mmm-use-old-command-keys nil "\
Non-nil means to Use the old command keys for MMM Mode.
MMM Mode commands then have no modifier while insertion commands have
a control modifier, i.e. `mmm-command-modifiers' is set to nil and
`mmm-insert-modifiers' is set to (control). If nil, the values of
these variables are as the default, or whatever the user has set them
to. This variable must be set before MMM Mode is loaded." :group 'mmm :type 'boolean)

(defcustom mmm-mode-hook nil "\
Hook run when MMM Mode is enabled in a buffer.

A hook named mmm-<major-mode>-hook is also run, if it exists. For
example, `mmm-html-mode-hook' is run whenever MMM Mode is entered with
HTML mode the dominant mode.

A hook named mmm-<submode>-submode-hook is run when a submode region
of a given mode is created. For example, `mmm-cperl-mode-submode-hook'
is run whenever a CPerl mode submode region is created, in any buffer.
When this hooks are run, point is guaranteed to be at the start of
the newly created submode region.

Finally, a hook named mmm-<class>-class-hook is run whenever a buffer
is first mmm-ified with a given submode class. For example,
`mmm-mason-class-hook' is run whenever the `mason' class is first
applied in a buffer." :group 'mmm :type 'hook)

(defcustom mmm-major-mode-hook nil "\
Hook run whenever a new major mode is finished starting up.
MMM Mode implements this with a hack (see comments in the source) so
that `mmm-global-mode' will function correctly, but makes this hook
available so that others can take advantage of the hack as well.

Note that file local variables have *not* been processed by the time
this hook is run. If a function needs to inspect them, it should also
be added to `find-file-hooks'. However, `find-file-hooks' is not run
when creating a non-file-based buffer, or when changing major modes in
an existing buffer." :group 'mmm :type 'hook)

(defcustom mmm-global-mode nil "\
*Specify in which buffers to turn on MMM Mode automatically.

- If nil, MMM Mode is never enabled automatically.
- If t, MMM Mode is enabled automatically in all buffers.
- If any other symbol, MMM mode is enabled only in those buffers that
  have submode classes associated with them. See `mmm-classes' and
  `mmm-mode-ext-classes-alist' for more information." :group 'mmm :type '(choice (const :tag "Always" t) (const :tag "Never" nil) (other :tag "Maybe" maybe)) :require 'mmm-mode)

(defcustom mmm-never-modes '(help-mode Info-mode dired-mode comint-mode telnet-mode shell-mode eshell-mode forms-mode) "\
List of modes in which MMM Mode is never activated." :group 'mmm :type '(repeat (symbol :tag "Mode")))

;;;***

(provide 'mmm-mode-custom-defines)
