;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'pcomplete-custom-defines) (error "Feature pcomplete-custom-defines already loaded"))

;;;### (autoloads (pcmpl-cvs-binary pcmpl-cvs) "pcmpl-cvs" "pcomplete/pcmpl-cvs.el")
(defconst custom-define-current-source-file "pcmpl-cvs.el")

(defgroup pcmpl-cvs nil "Functions for dealing with CVS completions" :group 'pcomplete)

(defcustom pcmpl-cvs-binary (or (executable-find "cvs") "cvs") "\
*The full path of the 'cvs' binary." :type 'file :group 'pcmpl-cvs)

;;;***

;;;### (autoloads (pcmpl-gnu-tarfile-regexp pcmpl-gnu-makefile-regexps pcmpl-gnu) "pcmpl-gnu" "pcomplete/pcmpl-gnu.el")
(defconst custom-define-current-source-file "pcmpl-gnu.el")

(defgroup pcmpl-gnu nil "Completions for GNU project tools." :group 'pcomplete)

(defcustom pcmpl-gnu-makefile-regexps '("\\`GNUmakefile" "\\`Makefile" "\\.mak\\'") "\
*A list of regexps that will match Makefile names." :type '(repeat regexp) :group 'pcmpl-gnu)

(defcustom pcmpl-gnu-tarfile-regexp "\\.t\\(ar\\(\\.\\(gz\\|bz2\\|Z\\)\\)?\\|gz\\|a[zZ]\\|z2\\)\\'" "\
*A regexp which matches any tar archive." :type 'regexp :group 'pcmpl-gnu)

;;;***

;;;### (autoloads (pcmpl-linux) "pcmpl-linux" "pcomplete/pcmpl-linux.el")
(defconst custom-define-current-source-file "pcmpl-linux.el")

(defgroup pcmpl-linux nil "Functions for dealing with GNU/Linux completions." :group 'pcomplete)

;;;***

;;;### (autoloads (pcmpl-rpm) "pcmpl-rpm" "pcomplete/pcmpl-rpm.el")
(defconst custom-define-current-source-file "pcmpl-rpm.el")

(defgroup pcmpl-rpm nil "Functions for dealing with CVS completions" :group 'pcomplete)

;;;***

;;;### (autoloads (pcmpl-unix-passwd-file pcmpl-unix-group-file) "pcmpl-unix" "pcomplete/pcmpl-unix.el")
(defconst custom-define-current-source-file "pcmpl-unix.el")

(defcustom pcmpl-unix-group-file "/etc/group" "\
*If non-nil, a string naming the group file on your system." :type 'file :group 'pcmpl-unix)

(defcustom pcmpl-unix-passwd-file "/etc/passwd" "\
*If non-nil, a string naming the passwd file on your system." :type 'file :group 'pcmpl-unix)

;;;***

;;;### (autoloads (pcomplete-use-paring pcomplete-default-completion-function pcomplete-command-name-function pcomplete-command-completion-function pcomplete-try-first-hook pcomplete-restore-window-delay pcomplete-cycle-cutoff-length pcomplete-cycle-completions pcomplete-parse-arguments-function pcomplete-expand-before-complete pcomplete-help pcomplete-compare-entry-function pcomplete-man-function pcomplete-quote-arg-hook pcomplete-arg-quote-list pcomplete-recexact pcomplete-suffix-list pcomplete-autolist pcomplete-ignore-case pcomplete-dir-ignore pcomplete-file-ignore pcomplete) "pcomplete" "pcomplete/pcomplete.el")
(defconst custom-define-current-source-file "pcomplete.el")

(defgroup pcomplete nil "Programmable completion." :group 'processes)

(defcustom pcomplete-file-ignore nil "\
*A regexp of filenames to be disregarded during file completion." :type 'regexp :group 'pcomplete)

(defcustom pcomplete-dir-ignore nil "\
*A regexp of names to be disregarded during directory completion." :type 'regexp :group 'pcomplete)

(defcustom pcomplete-ignore-case (memq system-type '(ms-dos windows-nt)) "\
*If non-nil, ignore case when doing filename completion." :type 'boolean :group 'pcomplete)

(defcustom pcomplete-autolist nil "\
*If non-nil, automatically list possibilities on partial completion.
This mirrors the optional behavior of tcsh." :type 'boolean :group 'pcomplete)

(defcustom pcomplete-suffix-list (list directory-sep-char ?:) "\
*A list of characters which constitute a proper suffix." :type '(repeat character) :group 'pcomplete)

(defcustom pcomplete-recexact nil "\
*If non-nil, use shortest completion if characters cannot be added.
This mirrors the optional behavior of tcsh.

A non-nil value is useful if `pcomplete-autolist' is non-nil too." :type 'boolean :group 'pcomplete)

(defcustom pcomplete-arg-quote-list nil "\
*List of characters to quote when completing an argument." :type '(choice (repeat character) (const :tag "Don't quote" nil)) :group 'pcomplete)

(defcustom pcomplete-quote-arg-hook nil "\
*A hook which is run to quote a character within a filename.
Each function is passed both the filename to be quoted, and the index
to be considered.  If the function wishes to provide an alternate
quoted form, it need only return the replacement string.  If no
function provides a replacement, quoting shall proceed as normal,
using a backslash to quote any character which is a member of
`pcomplete-arg-quote-list'." :type 'hook :group 'pcomplete)

(defcustom pcomplete-man-function (if (featurep 'xemacs) (function manual-entry) 'man) "\
*A function to that will be called to display a manual page.
It will be passed the name of the command to document." :type 'function :group 'pcomplete)

(defcustom pcomplete-compare-entry-function 'string-lessp "\
*This function is used to order file entries for completion.
The behavior of most all shells is to sort alphabetically." :type '(radio (function-item string-lessp) (function-item file-newer-than-file-p) (function :tag "Other")) :group 'pcomplete)

(defcustom pcomplete-help nil "\
*A string or function (or nil) used for context-sensitive help.
If a string, it should name an Info node that will be jumped to.
If non-nil, it must a sexp that will be evaluated, and whose
result will be shown in the minibuffer.
If nil, the function `pcomplete-man-function' will be called with the
current command argument." :type '(choice string sexp (const :tag "Use man page" nil)) :group 'pcomplete)

(defcustom pcomplete-expand-before-complete nil "\
*If non-nil, expand the current argument before completing it.
This means that typing something such as '$HOME/bi' followed by
\\[pcomplete-argument] will cause the variable reference to be
resolved first, and the resultant value that will be completed against
to be inserted in the buffer.  Note that exactly what gets expanded
and how is entirely up to the behavior of the
`pcomplete-parse-arguments-function'." :type 'boolean :group 'pcomplete)

(defcustom pcomplete-parse-arguments-function 'pcomplete-parse-buffer-arguments "\
*A function to call to parse the current line's arguments.
It should be called with no parameters, and with point at the position
of the argument that is to be completed.

It must either return nil, or a cons cell of the form:

  ((ARG...) (BEG-POS...))

The two lists must be identical in length.  The first gives the final
value of each command line argument (which need not match the textual
representation of that argument), and BEG-POS gives the beginning
position of each argument, as it is seen by the user.  The establishes
a relationship between the fully resolved value of the argument, and
the textual representation of the argument." :type 'function :group 'pcomplete)

(defcustom pcomplete-cycle-completions t "\
*If non-nil, hitting the TAB key cycles through the completion list.
Typical Emacs behavior is to complete as much as possible, then pause
waiting for further input.  Then if TAB is hit again, show a list of
possible completions.  When `pcomplete-cycle-completions' is non-nil,
it acts more like zsh or 4nt, showing the first maximal match first,
followed by any further matches on each subsequent pressing of the TAB
key.  \\[pcomplete-list] is the key to press if the user wants to see
the list of possible completions." :type 'boolean :group 'pcomplete)

(defcustom pcomplete-cycle-cutoff-length 5 "\
*If the number of completions is greater than this, don't cycle.
This variable is a compromise between the traditional Emacs style of
completion, and the \"cycling\" style.  Basically, if there are more
than this number of completions possible, don't automatically pick the
first one and then expect the user to press TAB to cycle through them.
Typically, when there are a large number of completion possibilities,
the user wants to see them in a list buffer so that they can know what
options are available.  But if the list is small, it means the user
has already entered enough input to disambiguate most of the
possibilities, and therefore they are probably most interested in
cycling through the candidates.  Set this value to nil if you want
cycling to always be enabled." :type '(choice integer (const :tag "Always cycle" nil)) :group 'pcomplete)

(defcustom pcomplete-restore-window-delay 1 "\
*The number of seconds to wait before restoring completion windows.
Once the completion window has been displayed, if the user then goes
on to type something else, that completion window will be removed from
the display (actually, the original window configuration before it was
displayed will be restored), after this many seconds of idle time.  If
set to nil, completion windows will be left on second until the user
removes them manually.  If set to 0, they will disappear immediately
after the user enters a key other than TAB." :type '(choice integer (const :tag "Never restore" nil)) :group 'pcomplete)

(defcustom pcomplete-try-first-hook nil "\
*A list of functions which are called before completing an argument.
This can be used, for example, for completing things which might apply
to all arguments, such as variable names after a $." :type 'hook :group 'pcomplete)

(defcustom pcomplete-command-completion-function (function (lambda nil (pcomplete-here (pcomplete-executables)))) "\
*Function called for completing the initial command argument." :type 'function :group 'pcomplete)

(defcustom pcomplete-command-name-function 'pcomplete-command-name "\
*Function called for determining the current command name." :type 'function :group 'pcomplete)

(defcustom pcomplete-default-completion-function (function (lambda nil (while (pcomplete-here (pcomplete-entries))))) "\
*Function called when no completion rule can be found.
This function is used to generate completions for every argument." :type 'function :group 'pcomplete)

(defcustom pcomplete-use-paring t "\
*If t, pare alternatives that have already been used.
If nil, you will always see the completion set of possible options, no
matter which of those options have already been used in previous
command arguments." :type 'boolean :group 'pcomplete)

;;;***

(provide 'pcomplete-custom-defines)
