;;; DO NOT MODIFY THIS FILE -*- coding: raw-text-unix -*-
;;;###coding system: raw-text-unix
(if (featurep 'sh-script-custom-defines) (error "Feature sh-script-custom-defines already loaded"))

;;;### (autoloads (executable-self-display executable-chmod executable-prefix executable-magicless-file-regexp executable-query executable-insert executable) "executable" "sh-script/executable.el")
(defconst custom-define-current-source-file "executable.el")

(defgroup executable nil "Base functionality for executable interpreter scripts" :group 'processes)

(defcustom executable-insert t "\
*Non-nil means offer to add a magic number to a file.
This takes effect when you switch to certain major modes,
including Shell-script mode (`sh-mode').
When you type \\[executable-set-magic], it always offers to add or
update the magic number." :type 'boolean :group 'executable)

(defcustom executable-query 'function "\
*If non-nil, ask user before changing an existing magic number.
When this is `function', only ask when called non-interactively." :type '(choice (const :tag "Don't Ask" nil) (const :tag "Ask when non-interactive" function) (other :tag "Ask" t)) :group 'executable)

(defcustom executable-magicless-file-regexp "/[Mm]akefile$\\|/\\.\\(z?profile\\|bash_profile\\|z?login\\|bash_login\\|z?logout\\|bash_logout\\|.+shrc\\|esrc\\|rcrc\\|[kz]shenv\\)$" "\
*On files with this kind of name no magic is inserted or changed." :type 'regexp :group 'executable)

(defcustom executable-prefix "#! " "\
*Interpreter magic number prefix inserted when there was no magic number." :type 'string :group 'executable)

(defcustom executable-chmod 73 "\
*After saving, if the file is not executable, set this mode.
This mode passed to `set-file-modes' is taken absolutely when negative, or
relative to the files existing modes.  Do nothing if this is nil.
Typical values are 73 (+x) or -493 (rwxr-xr-x)." :type '(choice integer (const nil)) :group 'executable)

(defcustom executable-self-display "tail" "\
*Command you use with argument `+2' to make text files self-display.
Note that the like of `more' doesn't work too well under Emacs \\[shell]." :type 'string :group 'executable)

;;;***

;;;### (autoloads (sh-indent-after-case sh-indent-after-switch sh-indent-after-function sh-indent-after-open sh-indent-for-continuation sh-indent-for-case-alt sh-indent-for-case-label sh-indent-after-done sh-indent-after-loop-construct sh-indent-after-do sh-indent-for-do sh-indent-for-then sh-indent-after-if sh-indent-after-else sh-indent-for-done sh-indent-for-fi sh-indent-for-else sh-indent-comment sh-basic-offset sh-first-lines-indent sh-blink sh-popup-occur-buffer sh-learn-basic-offset sh-mode-hook sh-set-shell-hook sh-indentation sh-other-keywords sh-leading-keywords sh-builtins sh-end-of-command sh-beginning-of-command sh-remember-variable-min sh-indentation sh-assignment-regexp sh-require-final-newline sh-dynamic-complete-functions sh-imenu-generic-expression sh-shell-arg sh-shell-file sh-alias-alist sh-ancestor-alist sh-script sh) "sh-script" "sh-script/sh-script.el")
(defconst custom-define-current-source-file "sh-script.el")

(defgroup sh nil "Shell programming utilities" :group 'unix :group 'languages)

(defgroup sh-script nil "Shell script mode" :group 'sh :prefix "sh-")

(defcustom sh-ancestor-alist '((ash . sh) (bash . jsh) (bash2 . jsh) (dtksh . ksh) (es . rc) (itcsh . tcsh) (jcsh . csh) (jsh . sh) (ksh . ksh88) (ksh88 . jsh) (oash . sh) (pdksh . ksh88) (posix . sh) (tcsh . csh) (wksh . ksh88) (wsh . sh) (zsh . ksh88) (rpm . sh)) "\
*Alist showing the direct ancestor of various shells.
This is the basis for `sh-feature'.  See also `sh-alias-alist'.
By default we have the following three hierarchies:

csh		C Shell
  jcsh		C Shell with Job Control
  tcsh		Toronto C Shell
    itcsh	? Toronto C Shell
rc		Plan 9 Shell
  es		Extensible Shell
sh		Bourne Shell
  ash		? Shell
  jsh		Bourne Shell with Job Control
    bash	GNU Bourne Again Shell
    ksh88	Korn Shell '88
      ksh	Korn Shell '93
	dtksh	CDE Desktop Korn Shell
      pdksh	Public Domain Korn Shell
      wksh	Window Korn Shell
      zsh	Z Shell
  oash		SCO OA (curses) Shell
  posix		IEEE 1003.2 Shell Standard
  wsh		? Shell" :type '(repeat (cons symbol symbol)) :group 'sh-script)

(defcustom sh-alias-alist (nconc (if (eq system-type 'linux) '((csh . tcsh) (ksh . pdksh))) '((ksh . ksh88) (bash2 . bash) (sh5 . sh))) "\
*Alist for transforming shell names to what they really are.
Use this where the name of the executable doesn't correspond to the type of
shell it really is." :type '(repeat (cons symbol symbol)) :group 'sh-script)

(defcustom sh-shell-file (or (and (memq system-type '(ms-dos windows-nt)) (let* ((shell (getenv "SHELL")) (shell-base (and shell (file-name-nondirectory shell)))) (if (or (null shell) (member (downcase shell-base) '("command.com" "cmd.exe" "4dos.com" "ndos.com" "cmdproxy.exe"))) "/bin/sh" (file-name-sans-extension (downcase shell))))) (getenv "SHELL") "/bin/sh") "\
*The executable file name for the shell being programmed." :type 'string :group 'sh-script)

(defcustom sh-shell-arg '((bash) (csh . "-f") (pdksh) (ksh88) (rc . "-p") (wksh) (zsh . "-f")) "\
*Single argument string for the magic number.  See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice (const :tag "No Arguments" nil) (string :tag "Arguments") (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defcustom sh-imenu-generic-expression (backquote ((sh (nil "^\\s-*\\(function\\s-+\\)?\\([A-Za-z_][A-Za-z_0-9]+\\)\\s-*()" 2)))) "\
*Alist of regular expressions for recognizing shell function definitions.
See `sh-feature' and `imenu-generic-expression'." :type '(alist :key-type (symbol :tag "Shell") :value-type (alist :key-type (choice :tag "Title" string (const :tag "None" nil)) :value-type (repeat :tag "Regexp, index..." sexp))) :group 'sh-script :version "20.4")

(defcustom sh-dynamic-complete-functions '(shell-dynamic-complete-environment-variable shell-dynamic-complete-command comint-dynamic-complete-filename) "\
*Functions for doing TAB dynamic completion." :type '(repeat function) :group 'sh-script)

(defcustom sh-require-final-newline '((csh . t) (pdksh . t) (rc eval . require-final-newline) (sh eval . require-final-newline)) "\
*Value of `require-final-newline' in Shell-Script mode buffers.
See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice (const :tag "require" t) (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defcustom sh-assignment-regexp '((csh . "\\<\\([a-zA-Z0-9_]+\\)\\(\\[.+\\]\\)?[ 	]*[-+*/%^]?=") (ksh88 . "\\<\\([a-zA-Z0-9_]+\\)\\(\\[.+\\]\\)?[ 	]*\\([-+*/%&|~^]\\|<<\\|>>\\)?=") (rc . "\\<\\([a-zA-Z0-9_*]+\\)[ 	]*=") (sh . "\\<\\([a-zA-Z0-9_]+\\)=")) "\
*Regexp for the variable name and what may follow in an assignment.
First grouping matches the variable name.  This is upto and including the `='
sign.  See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice regexp (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defcustom sh-indentation 4 "\
The width for further indentation in Shell-Script mode." :type 'integer :group 'sh-script)

(defcustom sh-remember-variable-min 3 "\
*Don't remember variables less than this length for completing reads." :type 'integer :group 'sh-script)

(defcustom sh-beginning-of-command "\\([;({`|&]\\|\\`\\|[^\\]\n\\)[ 	]*\\([/~a-zA-Z0-9:]\\)" "\
*Regexp to determine the beginning of a shell command.
The actual command starts at the beginning of the second \\(grouping\\)." :type 'regexp :group 'sh-script)

(defcustom sh-end-of-command "\\([/~a-zA-Z0-9:]\\)[ 	]*\\([;#)}`|&]\\|$\\)" "\
*Regexp to determine the end of a shell command.
The actual command ends at the end of the first \\(grouping\\)." :type 'regexp :group 'sh-script)

(defcustom sh-builtins '((bash eval sh-append posix "alias" "bg" "bind" "builtin" "declare" "dirs" "enable" "fc" "fg" "help" "history" "jobs" "kill" "let" "local" "popd" "pushd" "source" "suspend" "typeset" "unalias") (bourne eval sh-append shell "eval" "export" "getopts" "newgrp" "pwd" "read" "readonly" "times" "ulimit") (csh eval sh-append shell "alias" "chdir" "glob" "history" "limit" "nice" "nohup" "rehash" "setenv" "source" "time" "unalias" "unhash") (dtksh eval identity wksh) (es "access" "apids" "cd" "echo" "eval" "false" "let" "limit" "local" "newpgrp" "result" "time" "umask" "var" "vars" "wait" "whatis") (jsh eval sh-append sh "bg" "fg" "jobs" "kill" "stop" "suspend") (jcsh eval sh-append csh "bg" "fg" "jobs" "kill" "notify" "stop" "suspend") (ksh88 eval sh-append bourne "alias" "bg" "false" "fc" "fg" "jobs" "kill" "let" "print" "time" "typeset" "unalias" "whence") (oash eval sh-append sh "checkwin" "dateline" "error" "form" "menu" "newwin" "oadeinit" "oaed" "oahelp" "oainit" "pp" "ppfile" "scan" "scrollok" "wattr" "wclear" "werase" "win" "wmclose" "wmmessage" "wmopen" "wmove" "wmtitle" "wrefresh") (pdksh eval sh-append ksh88 "bind") (posix eval sh-append sh "command") (rc "builtin" "cd" "echo" "eval" "limit" "newpgrp" "shift" "umask" "wait" "whatis") (sh eval sh-append bourne "hash" "test" "type") (shell "cd" "echo" "eval" "set" "shift" "umask" "unset" "wait") (wksh eval sh-append ksh88 "Xt[A-Z][A-Za-z]*") (zsh eval sh-append ksh88 "autoload" "bindkey" "builtin" "chdir" "compctl" "declare" "dirs" "disable" "disown" "echotc" "enable" "functions" "getln" "hash" "history" "integer" "limit" "local" "log" "popd" "pushd" "r" "readonly" "rehash" "sched" "setopt" "source" "suspend" "true" "ttyctl" "type" "unfunction" "unhash" "unlimit" "unsetopt" "vared" "which")) "\
*List of all shell builtins for completing read and fontification.
Note that on some systems not all builtins are available or some are
implemented as aliases.  See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice (repeat string) (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defcustom sh-leading-keywords '((csh "else") (es "true" "unwind-protect" "whatis") (rc "else") (sh "do" "elif" "else" "if" "then" "trap" "type" "until" "while")) "\
*List of keywords that may be immediately followed by a builtin or keyword.
Given some confusion between keywords and builtins depending on shell and
system, the distinction here has been based on whether they influence the
flow of control or syntax.  See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice (repeat string) (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defcustom sh-other-keywords '((bash eval sh-append bourne "bye" "logout") (bourne eval sh-append sh "function") (csh eval sh-append shell "breaksw" "default" "end" "endif" "endsw" "foreach" "goto" "if" "logout" "onintr" "repeat" "switch" "then" "while") (es "break" "catch" "exec" "exit" "fn" "for" "forever" "fork" "if" "return" "throw" "while") (ksh88 eval sh-append bourne "select") (rc "break" "case" "exec" "exit" "fn" "for" "if" "in" "return" "switch" "while") (sh eval sh-append shell "done" "esac" "fi" "for" "in" "return") (shell "break" "case" "continue" "exec" "exit") (zsh eval sh-append bash "select")) "\
*List of keywords not in `sh-leading-keywords'.
See `sh-feature'." :type '(repeat (cons (symbol :tag "Shell") (choice (repeat string) (cons :format "Evaluate: %v" (const :format "" eval) sexp)))) :group 'sh-script)

(defgroup sh-indentation nil "Variables controlling indentation in shell scripts.\n\nNote: customizing these variables will not affect existing buffers if\n`sh-make-vars-local' is no-nil.  See the documentation for\nvariable `sh-make-vars-local', command `sh-make-vars-local'\nand command `sh-reset-indent-vars-to-global-values'." :group 'sh-script)

(defcustom sh-set-shell-hook nil "\
*Hook run by `sh-set-shell'." :type 'hook :group 'sh-script)

(defcustom sh-mode-hook nil "\
*Hook run by `sh-mode'." :type 'hook :group 'sh-script)

(defcustom sh-learn-basic-offset nil "\
*When `sh-guess-basic-offset' should learn `sh-basic-offset'.

nil mean:              never.
t means:               only if there seems to be an obvious value.
Anything else means:   whenever we have a \"good guess\" as to the value." :type '(choice (const :tag "Never" nil) (const :tag "Only if sure" t) (const :tag "If have a good guess" usually)) :group 'sh-indentation)

(defcustom sh-popup-occur-buffer nil "\
*Controls when  `sh-learn-buffer-indent' pops the *indent* buffer.
If t it is always shown.  If nil, it is shown only when there
are conflicts." :type '(choice (const :tag "Only when there are conflicts." nil) (const :tag "Always" t)) :group 'sh-indentation)

(defcustom sh-blink t "\
*If non-nil, `sh-show-indent' shows the line indentation is relative to.
The position on the line is not necessarily meaningful.
In some cases the line will be the matching keyword, but this is not
always the case." :type 'boolean :group 'sh-indentation)

(defcustom sh-first-lines-indent 0 "\
*The indentation of the first non-blank non-comment line.
Usually 0 meaning first column.
Can be set to a number, or to nil which means leave it as is." :type '(choice (const :tag "Leave as is" nil) (integer :tag "Column number" :menu-tag "Indent to this col (0 means first col)")) :group 'sh-indentation)

(defcustom sh-basic-offset 4 "\
*The default indentation increment.
This value is used for the + and - symbols in an indentation variable." :type 'integer :group 'sh-indentation)

(defcustom sh-indent-comment nil "\
*How a comment line is to be indented.
nil means leave it as it is;
t  means indent it as a normal line, aligning it to previous non-blank
   non-comment line;
a number means align to that column, e.g. 0 means fist column." :type '(choice (const :tag "Leave as is." nil) (const :tag "Indent as a normal line." t) (integer :menu-tag "Indent to this col (0 means first col)." :tag "Indent to column number.")) :group 'sh-indentation)

(defcustom sh-indent-for-else 0 "\
*How much to indent an else relative to an if.  Usually 0." :type (backquote (choice (integer :menu-tag "A number (positive=>indent right)" :tag "A number") (const :tag "--") (\,@ sh-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-fi 0 "\
*How much to indent a fi relative to an if.  Usually 0." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-done '0 "\
*How much to indent a done relative to its matching stmt.  Usually 0." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-else '+ "\
*How much to indent a statement after an else statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-if '+ "\
*How much to indent a statement after an if statement.
This includes lines after else and elif statements, too, but
does not affect then else elif or fi statements themselves." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-then '+ "\
*How much to indent a then relative to an if." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-do '* "\
*How much to indent a do statement.
This is relative to the statement before the do, i.e. the
while until or for statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-do '* "\
*How much to indent a line after a do statement.
This is used when the do is the first word of the line.
This is relative to the statement before the do, e.g. a
while for repeat or select statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-loop-construct '+ "\
*How much to indent a statement after a loop construct.

This variable is used when the keyword \"do\" is on the same line as the
loop statement (e.g.  \"until\", \"while\" or \"for\").
If the do is on a line by itself, then `sh-indent-after-do' is used instead." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-done 0 "\
*How much to indent a statement after a \"done\" keyword.
Normally this is 0, which aligns the \"done\" to the matching
looping construct line.
Setting it non-zero allows you to have the \"do\" statement on a line
by itself and align the done under to do." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-case-label '+ "\
*How much to indent a case label statement.
This is relative to the line containing the case statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-case-alt '++ "\
*How much to indent statements after the case label.
This is relative to the line containing the case statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-for-continuation '+ "\
*How much to indent for a continuation statement." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-open '+ "\
*How much to indent after a line with an opening parenthesis or brace.
For an open paren after a function `sh-indent-after-function' is used." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-function '+ "\
*How much to indent after a function line." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-switch '+ "\
*How much to indent a case statement relative to the switch statement.
This is for the rc shell." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

(defcustom sh-indent-after-case '+ "\
*How much to indent a statement relative to the case statement.
This is for the rc shell." :type (backquote (choice (\,@ sh-number-or-symbol-list))) :group 'sh-indentation)

;;;***

(provide 'sh-script-custom-defines)
